# DirectGuiExtension
A set of extensions for the DirectGUI system of the Panda3D engine

## Features
Extends the DirectGUI system with the following features

Simple layout system
- DirectAutoSizer
- DirectBoxSizer
- DirectGridSizer
- DirectSplitFrame

Widgets
- DirectDatePicker
- DirectDiagram
- DirectMenuItem
- DirectSpinBox
- DirectTooltip

Window system
- DirectScrolledWindowFrame

Helper Class
- DirectGuiHelper

## Install
Install the DirectGuiExtension via pip

```bash
pip install DirectGuiExtension
```

## How to use

Check the wiki on github for a detailed documentation about how to use the individual elements of this extension:<br>
<a href="https://github.com/fireclawthefox/DirectGuiExtension/wiki">wiki</a> (https://github.com/fireclawthefox/DirectGuiExtension/wiki)
